Igt-dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Bommu Krishnaiah <krishnaiah.bommu@intel.com>
To: igt-dev@lists.freedesktop.org
Cc: Bommu Krishnaiah <krishnaiah.bommu@intel.com>,
	Oak Zeng <oak.zeng@intel.com>,
	Himal Prasad Ghimiray <himal.prasad.ghimiray@intel.com>
Subject: [PATCH i-g-t v2 05/10] tests/intel/xe_svm: svm-huge-page
Date: Tue, 14 May 2024 12:40:21 +0530	[thread overview]
Message-ID: <20240514071026.748257-6-krishnaiah.bommu@intel.com> (raw)
In-Reply-To: <20240514071026.748257-1-krishnaiah.bommu@intel.com>

Verify GPU can huge page access by using svm.

Signed-off-by: Bommu Krishnaiah <krishnaiah.bommu@intel.com>
Cc: Oak Zeng <oak.zeng@intel.com>
Cc: Himal Prasad Ghimiray <himal.prasad.ghimiray@intel.com>
---
 tests/intel/xe_svm.c | 52 ++++++++++++++++++++++++++++++++++++++++++--
 1 file changed, 50 insertions(+), 2 deletions(-)

diff --git a/tests/intel/xe_svm.c b/tests/intel/xe_svm.c
index 1c90d2e10..4f2818cc8 100644
--- a/tests/intel/xe_svm.c
+++ b/tests/intel/xe_svm.c
@@ -27,8 +27,9 @@
  * SUBTEST: svm-basic-mmap
  * Description: verify SVM basic functionality by using mmap
  * SUBTEST: svm-random-access
  * Description: verify SVM basic functionality by using
  * randomly access any location in malloc'ed memory
  */
 
 #include <fcntl.h>
@@ -145,6 +146,49 @@ static void svm_random_access(int fd, uint32_t vm, struct drm_xe_engine_class_in
 	free(dst);
 }
 
+/**
+ * Test the behavior of transparent huge page.
+ * Allocate 2MB of aligned memory so huge page
+ * is used. What happens if driver only migrate
+ * 1 4k page of that buffer to GPU?
+ *
+ * Test result shows that the huge page is splitted
+ * into small pages and only one 4k page is
+ * migrated.
+ */
+static void svm_thp(int fd, uint32_t vm, struct drm_xe_engine_class_instance *eci)
+{
+	uint64_t gpu_va = 0x1a0000;
+	size_t bo_size = xe_bb_size(fd, PAGE_ALIGN_UFENCE);
+	uint32_t size = 1<<21;
+	uint32_t *dst;
+	int ret;
+
+	struct xe_buffer cmd_buf = {
+		.fd = fd,
+		.gpu_addr = (void *)(uintptr_t)gpu_va,
+		.vm = vm,
+		.size = bo_size,
+		.placement = vram_if_possible(fd, eci->gt_id),
+		.flag = DRM_XE_GEM_CREATE_FLAG_NEEDS_VISIBLE_VRAM,
+	};
+
+	ret = posix_memalign((void **)&dst, size, size);
+	igt_assert_eq(ret, 0);
+	/** TODO huge page advice cause the system hang
+	* when process exit...Very possible a hmm bug
+	**/
+	memset(dst, 0xbe, size);
+
+	xe_create_cmdbuf(&cmd_buf, insert_store, (uint64_t)dst, 0xc0ffee, eci);
+	xe_submit_cmd(&cmd_buf);
+
+	igt_assert_eq(*dst, 0xc0ffee);
+
+	xe_destroy_cmdbuf(&cmd_buf);
+	free(dst);
+}
+
 igt_main
 {
 	int fd;
@@ -175,6 +219,10 @@ igt_main
 		xe_for_each_engine(fd, hwe)
 			svm_random_access(fd, vm, hwe);
 
+	igt_subtest_f("svm-huge-page")
+		xe_for_each_engine(fd, hwe)
+			svm_thp(fd, vm, hwe);
+
 	igt_fixture {
 		xe_vm_destroy(fd, vm);
 		drm_close_driver(fd);
@@ -27,8 +27,9 @@
  * Description: verify SVM basic functionality by using mmap
  * SUBTEST: svm-random-access
- * Description: verify SVM basic functionality by using
- * randomly access any location in malloc'ed memory
+ * Description: verify SVM basic functionality by using randomly access any location in malloc'ed memory
+ * SUBTEST: svm-huge-page
+ * Description: verify SVM basic functionality by using huge page access
  */
 
-- 
2.25.1


  parent reply	other threads:[~2024-05-14  7:10 UTC|newest]

Thread overview: 16+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-05-14  7:10 [PATCH i-g-t v2 00/10] helper function Bommu Krishnaiah
2024-05-14  7:10 ` [PATCH i-g-t v2 01/10] lib/xe/xe_util: Introduce helper functions for buffer creation and command submission etc Bommu Krishnaiah
2024-05-14  7:10 ` [PATCH i-g-t v2 02/10] tests/intel/xe_svm: basic xe_svm test Bommu Krishnaiah
2024-05-14  7:10 ` [PATCH i-g-t v2 03/10] tests/xe_svm: basic svm test Bommu Krishnaiah
2024-05-15 17:38   ` Kamil Konieczny
2024-05-14  7:10 ` [PATCH i-g-t v2 04/10] tests/intel/xe_svm: svm_random_access Bommu Krishnaiah
2024-05-14  7:10 ` Bommu Krishnaiah [this message]
2024-05-14  7:10 ` [PATCH i-g-t v2 06/10] tests/intel/xe_svm: svm_atomic_access Bommu Krishnaiah
2024-05-14  8:14   ` Lisovskiy, Stanislav
2024-05-14  7:10 ` [PATCH i-g-t v2 07/10] tests/intel/xe_svm: svm-invalid-va Bommu Krishnaiah
2024-05-14  7:10 ` [PATCH i-g-t v2 08/10] tests/intel/xe_svm: svm_benchmark Bommu Krishnaiah
2024-05-14  7:10 ` [PATCH i-g-t v2 09/10] tests/intel/xe_svm: svm_mprotect Bommu Krishnaiah
2024-05-14  7:10 ` [PATCH i-g-t v2 10/10] tests/intel/xe_svm: svm-sparse-access Bommu Krishnaiah
2024-05-14  7:52 ` ✗ Fi.CI.BUILD: failure for helper function (rev2) Patchwork
2024-05-14  7:58 ` ✗ GitLab.Pipeline: warning " Patchwork
2024-05-15 17:29 ` [PATCH i-g-t v2 00/10] helper function Kamil Konieczny

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240514071026.748257-6-krishnaiah.bommu@intel.com \
    --to=krishnaiah.bommu@intel.com \
    --cc=himal.prasad.ghimiray@intel.com \
    --cc=igt-dev@lists.freedesktop.org \
    --cc=oak.zeng@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox